==> cloud-4.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/organisms/EntityFormPanel.tsx <==
import PanelWrapper from 'atoms/PanelWrapper';
import EntityFormRecord from 'model/EntityFormRecord';
import EntityFormBlock from 'molecules/EntityFormBlock';
import { calcPanelName } from 'service/utility';

/**
 * Determines whether or not to display the form.
 *
 * Some pages require fine control over the display of forms.
 * Therefore, this function determines whether or not to display the form.
 * @param cloudServiceProvider The cloud service provider.
 * @param entityName The entity's type name.
 * @param actionType The CxUD action Type.
 * @param labelName The label name of this form block.
 * @param formData The data of form values.
 *
 * @returns If TRUE, the block is displayed.
 */
const showEntityFormBlockFlg = (
  cloudServiceProvider: string,
  entityName: string,
  actionType: string,
  labelName: string,
  formData: Record<string, any>
) => {
  // Create K8s Deployment
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'deployment') {
    if (labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  // Create K8s pod
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'pod') {
    if (labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  return true;
}

const EntityFormPanel = ({
  cloudServiceProvider,
  cloudContext,
  entityName,
  actionType,
  entityRecord,
  formData,
  setFormData
}: {
  cloudServiceProvider: string,
  cloudContext: string,
  entityName: string,
  actionType: string,
  entityRecord: EntityFormRecord,
  formData: Record<string, any>,
  setFormData: (f: Record<string, any>) => void,
}) => {
  if (entityRecord.type !== 'panel') {
    return <></>;
  }

  return <PanelWrapper key={entityRecord.panelName}
    titleKey={entityRecord.panelName}
    title={calcPanelName(entityRecord.panelName, entityName)}>
    {
      entityRecord.keyValueRecords.map((keyValueRecord, index) => {
        return (showEntityFormBlockFlg(
          cloudServiceProvider,
          entityName,
          actionType,
          keyValueRecord.labelName,
          formData
        ))
          ? <EntityFormBlock key={index}
            keyValueRecord={keyValueRecord}
            cloudContext={cloudContext}
            formData={formData}
            setFormData={setFormData} />
          : <></>;
      })
    }
  </PanelWrapper>;
}

export default EntityFormPanel;

==> cloud-4.3.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/organisms/EntityFormPanel.tsx <==
import PanelWrapper from 'atoms/PanelWrapper';
import EntityFormColumn from 'model/EntityFormColumn';
import EntityFormRecord from 'model/EntityFormRecord';
import EntityFormBlock from 'molecules/EntityFormBlock';
import { calcPanelName } from 'service/utility';

/**
 * Determines whether or not to display the form.
 *
 * Some pages require fine control over the display of forms.
 * Therefore, this function determines whether or not to display the form.
 * @param cloudServiceProvider The cloud service provider.
 * @param entityName The entity's type name.
 * @param actionType The CxUD action Type.
 * @param entityFormColumn The entity form column.
 * @param formData The data of form values.
 *
 * @returns If TRUE, the block is displayed.
 */
const showEntityFormBlockFlg = (
  cloudServiceProvider: string,
  entityName: string,
  actionType: string,
  entityFormColumn: EntityFormColumn,
  formData: Record<string, any>
) => {
  // Create K8s deployment
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'deployment') {
    if (entityFormColumn.labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (entityFormColumn.labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(entityFormColumn.labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  // Create K8s pod
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'pod') {
    if (entityFormColumn.labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (entityFormColumn.labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(entityFormColumn.labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  // Associate OpenStack Floating IP
  if (actionType === 'associate'
    && cloudServiceProvider === 'openstack'
    && entityName === 'floating_ip') {
    if (entityFormColumn.type === 'select') {
      switch (entityFormColumn.name) {
        case 'instance_id':
          return formData['resource_type'] === 'instance';
        case 'instance_private_ip':
          return formData['resource_type'] === 'instance';
        case 'network_interface_id':
          return formData['resource_type'] === 'network_interface';
        case 'network_interface_private_ip':
          return formData['resource_type'] === 'network_interface';
      }
    }
  }

  return true;
}

const EntityFormPanel = ({
  cloudServiceProvider,
  cloudContext,
  entityName,
  actionType,
  entityRecord,
  formData,
  setFormData
}: {
  cloudServiceProvider: string,
  cloudContext: string,
  entityName: string,
  actionType: string,
  entityRecord: EntityFormRecord,
  formData: Record<string, any>,
  setFormData: (f: Record<string, any>) => void,
}) => {
  if (entityRecord.type !== 'panel') {
    return <></>;
  }

  return <PanelWrapper title={calcPanelName(entityRecord.panelName, entityName)}>
    {
      entityRecord.keyValueRecords.map((keyValueRecord, index) => {
        return (showEntityFormBlockFlg(
          cloudServiceProvider,
          entityName,
          actionType,
          keyValueRecord,
          formData
        ))
          ? <EntityFormBlock key={index}
            keyValueRecord={keyValueRecord}
            cloudContext={cloudContext}
            formData={formData}
            setFormData={setFormData} />
          : <></>;
      })
    }
  </PanelWrapper>;
}

export default EntityFormPanel;
